----------------
Django-Merchant
----------------

Django-Merchant is a django application that enables you to use
multiple payment processors from a single API.

Gateways
---------

Following gateways are supported:

* Authorize.net
* Paypal
* Eway
* Braintree Payments (Server to Server)
* Stripe
* Samurai from Fee Fighters
* Paylane
* WePay
* Beanstream
* Chargebee

Off-Site Processing
--------------------

* Paypal
* RBS WorldPay
* Google Checkout
* Amazon FPS
* Braintree Payments (Transparent Redirect)
* Stripe.js
* Samurai
* eWAY
* Authorize.net Direct Post Method

Documentation
--------------

Documentation is automatically built and published online at:

http://readthedocs.org/docs/django-merchant/en/latest/

Support
--------

There is a mailing list where discussion regarding the development
and usage of merchant happens:

http://groups.google.com/group/django-merchant/
